@@ -58,75 +58,79 @@
      TK_WRITEBUFFERCODE = 284,
      TK_SEGCOUNTCODE = 285,
      TK_CHARBUFFERCODE = 286,
-     TK_METHODCODE = 287,
-     TK_FROMTYPE = 288,
-     TK_TOTYPE = 289,
-     TK_TOSUBCLASS = 290,
-     TK_INCLUDE = 291,
-     TK_OPTINCLUDE = 292,
-     TK_IMPORT = 293,
-     TK_EXPHEADERCODE = 294,
-     TK_MODHEADERCODE = 295,
-     TK_TYPEHEADERCODE = 296,
-     TK_MODULE = 297,
-     TK_CMODULE = 298,
-     TK_CLASS = 299,
-     TK_STRUCT = 300,
-     TK_PUBLIC = 301,
-     TK_PROTECTED = 302,
-     TK_PRIVATE = 303,
-     TK_SIGNALS = 304,
-     TK_SLOTS = 305,
-     TK_BOOL = 306,
-     TK_SHORT = 307,
-     TK_INT = 308,
-     TK_LONG = 309,
-     TK_FLOAT = 310,
-     TK_DOUBLE = 311,
-     TK_CHAR = 312,
-     TK_VOID = 313,
-     TK_PYOBJECT = 314,
-     TK_PYTUPLE = 315,
-     TK_PYLIST = 316,
-     TK_PYDICT = 317,
-     TK_PYCALLABLE = 318,
-     TK_PYSLICE = 319,
-     TK_PYTYPE = 320,
-     TK_VIRTUAL = 321,
-     TK_ENUM = 322,
-     TK_SIGNED = 323,
-     TK_UNSIGNED = 324,
-     TK_SCOPE = 325,
-     TK_LOGICAL_OR = 326,
-     TK_CONST = 327,
-     TK_STATIC = 328,
-     TK_SIPSIGNAL = 329,
-     TK_SIPSLOT = 330,
-     TK_SIPANYSLOT = 331,
-     TK_SIPRXCON = 332,
-     TK_SIPRXDIS = 333,
-     TK_SIPSLOTCON = 334,
-     TK_SIPSLOTDIS = 335,
-     TK_NUMBER = 336,
-     TK_REAL = 337,
-     TK_TYPEDEF = 338,
-     TK_NAMESPACE = 339,
-     TK_TIMELINE = 340,
-     TK_PLATFORMS = 341,
-     TK_FEATURE = 342,
-     TK_LICENSE = 343,
-     TK_QCHAR = 344,
-     TK_TRUE = 345,
-     TK_FALSE = 346,
-     TK_NULL = 347,
-     TK_OPERATOR = 348,
-     TK_THROW = 349,
-     TK_QOBJECT = 350,
-     TK_EXCEPTION = 351,
-     TK_RAISECODE = 352,
-     TK_EXPLICIT = 353,
-     TK_TEMPLATE = 354,
-     TK_ELLIPSIS = 355
+     TK_PICKLECODE = 287,
+     TK_METHODCODE = 288,
+     TK_FROMTYPE = 289,
+     TK_TOTYPE = 290,
+     TK_TOSUBCLASS = 291,
+     TK_INCLUDE = 292,
+     TK_OPTINCLUDE = 293,
+     TK_IMPORT = 294,
+     TK_EXPHEADERCODE = 295,
+     TK_MODHEADERCODE = 296,
+     TK_TYPEHEADERCODE = 297,
+     TK_MODULE = 298,
+     TK_CMODULE = 299,
+     TK_CONSMODULE = 300,
+     TK_COMPOMODULE = 301,
+     TK_CLASS = 302,
+     TK_STRUCT = 303,
+     TK_PUBLIC = 304,
+     TK_PROTECTED = 305,
+     TK_PRIVATE = 306,
+     TK_SIGNALS = 307,
+     TK_SLOTS = 308,
+     TK_BOOL = 309,
+     TK_SHORT = 310,
+     TK_INT = 311,
+     TK_LONG = 312,
+     TK_FLOAT = 313,
+     TK_DOUBLE = 314,
+     TK_CHAR = 315,
+     TK_WCHAR_T = 316,
+     TK_VOID = 317,
+     TK_PYOBJECT = 318,
+     TK_PYTUPLE = 319,
+     TK_PYLIST = 320,
+     TK_PYDICT = 321,
+     TK_PYCALLABLE = 322,
+     TK_PYSLICE = 323,
+     TK_PYTYPE = 324,
+     TK_VIRTUAL = 325,
+     TK_ENUM = 326,
+     TK_SIGNED = 327,
+     TK_UNSIGNED = 328,
+     TK_SCOPE = 329,
+     TK_LOGICAL_OR = 330,
+     TK_CONST = 331,
+     TK_STATIC = 332,
+     TK_SIPSIGNAL = 333,
+     TK_SIPSLOT = 334,
+     TK_SIPANYSLOT = 335,
+     TK_SIPRXCON = 336,
+     TK_SIPRXDIS = 337,
+     TK_SIPSLOTCON = 338,
+     TK_SIPSLOTDIS = 339,
+     TK_NUMBER = 340,
+     TK_REAL = 341,
+     TK_TYPEDEF = 342,
+     TK_NAMESPACE = 343,
+     TK_TIMELINE = 344,
+     TK_PLATFORMS = 345,
+     TK_FEATURE = 346,
+     TK_LICENSE = 347,
+     TK_QCHAR = 348,
+     TK_TRUE = 349,
+     TK_FALSE = 350,
+     TK_NULL = 351,
+     TK_OPERATOR = 352,
+     TK_THROW = 353,
+     TK_QOBJECT = 354,
+     TK_EXCEPTION = 355,
+     TK_RAISECODE = 356,
+     TK_EXPLICIT = 357,
+     TK_TEMPLATE = 358,
+     TK_ELLIPSIS = 359
    };
 #endif
 #define TK_OPTIONS 258
@@ -158,81 +162,85 @@
 #define TK_WRITEBUFFERCODE 284
 #define TK_SEGCOUNTCODE 285
 #define TK_CHARBUFFERCODE 286
-#define TK_METHODCODE 287
-#define TK_FROMTYPE 288
-#define TK_TOTYPE 289
-#define TK_TOSUBCLASS 290
-#define TK_INCLUDE 291
-#define TK_OPTINCLUDE 292
-#define TK_IMPORT 293
-#define TK_EXPHEADERCODE 294
-#define TK_MODHEADERCODE 295
-#define TK_TYPEHEADERCODE 296
-#define TK_MODULE 297
-#define TK_CMODULE 298
-#define TK_CLASS 299
-#define TK_STRUCT 300
-#define TK_PUBLIC 301
-#define TK_PROTECTED 302
-#define TK_PRIVATE 303
-#define TK_SIGNALS 304
-#define TK_SLOTS 305
-#define TK_BOOL 306
-#define TK_SHORT 307
-#define TK_INT 308
-#define TK_LONG 309
-#define TK_FLOAT 310
-#define TK_DOUBLE 311
-#define TK_CHAR 312
-#define TK_VOID 313
-#define TK_PYOBJECT 314
-#define TK_PYTUPLE 315
-#define TK_PYLIST 316
-#define TK_PYDICT 317
-#define TK_PYCALLABLE 318
-#define TK_PYSLICE 319
-#define TK_PYTYPE 320
-#define TK_VIRTUAL 321
-#define TK_ENUM 322
-#define TK_SIGNED 323
-#define TK_UNSIGNED 324
-#define TK_SCOPE 325
-#define TK_LOGICAL_OR 326
-#define TK_CONST 327
-#define TK_STATIC 328
-#define TK_SIPSIGNAL 329
-#define TK_SIPSLOT 330
-#define TK_SIPANYSLOT 331
-#define TK_SIPRXCON 332
-#define TK_SIPRXDIS 333
-#define TK_SIPSLOTCON 334
-#define TK_SIPSLOTDIS 335
-#define TK_NUMBER 336
-#define TK_REAL 337
-#define TK_TYPEDEF 338
-#define TK_NAMESPACE 339
-#define TK_TIMELINE 340
-#define TK_PLATFORMS 341
-#define TK_FEATURE 342
-#define TK_LICENSE 343
-#define TK_QCHAR 344
-#define TK_TRUE 345
-#define TK_FALSE 346
-#define TK_NULL 347
-#define TK_OPERATOR 348
-#define TK_THROW 349
-#define TK_QOBJECT 350
-#define TK_EXCEPTION 351
-#define TK_RAISECODE 352
-#define TK_EXPLICIT 353
-#define TK_TEMPLATE 354
-#define TK_ELLIPSIS 355
+#define TK_PICKLECODE 287
+#define TK_METHODCODE 288
+#define TK_FROMTYPE 289
+#define TK_TOTYPE 290
+#define TK_TOSUBCLASS 291
+#define TK_INCLUDE 292
+#define TK_OPTINCLUDE 293
+#define TK_IMPORT 294
+#define TK_EXPHEADERCODE 295
+#define TK_MODHEADERCODE 296
+#define TK_TYPEHEADERCODE 297
+#define TK_MODULE 298
+#define TK_CMODULE 299
+#define TK_CONSMODULE 300
+#define TK_COMPOMODULE 301
+#define TK_CLASS 302
+#define TK_STRUCT 303
+#define TK_PUBLIC 304
+#define TK_PROTECTED 305
+#define TK_PRIVATE 306
+#define TK_SIGNALS 307
+#define TK_SLOTS 308
+#define TK_BOOL 309
+#define TK_SHORT 310
+#define TK_INT 311
+#define TK_LONG 312
+#define TK_FLOAT 313
+#define TK_DOUBLE 314
+#define TK_CHAR 315
+#define TK_WCHAR_T 316
+#define TK_VOID 317
+#define TK_PYOBJECT 318
+#define TK_PYTUPLE 319
+#define TK_PYLIST 320
+#define TK_PYDICT 321
+#define TK_PYCALLABLE 322
+#define TK_PYSLICE 323
+#define TK_PYTYPE 324
+#define TK_VIRTUAL 325
+#define TK_ENUM 326
+#define TK_SIGNED 327
+#define TK_UNSIGNED 328
+#define TK_SCOPE 329
+#define TK_LOGICAL_OR 330
+#define TK_CONST 331
+#define TK_STATIC 332
+#define TK_SIPSIGNAL 333
+#define TK_SIPSLOT 334
+#define TK_SIPANYSLOT 335
+#define TK_SIPRXCON 336
+#define TK_SIPRXDIS 337
+#define TK_SIPSLOTCON 338
+#define TK_SIPSLOTDIS 339
+#define TK_NUMBER 340
+#define TK_REAL 341
+#define TK_TYPEDEF 342
+#define TK_NAMESPACE 343
+#define TK_TIMELINE 344
+#define TK_PLATFORMS 345
+#define TK_FEATURE 346
+#define TK_LICENSE 347
+#define TK_QCHAR 348
+#define TK_TRUE 349
+#define TK_FALSE 350
+#define TK_NULL 351
+#define TK_OPERATOR 352
+#define TK_THROW 353
+#define TK_QOBJECT 354
+#define TK_EXCEPTION 355
+#define TK_RAISECODE 356
+#define TK_EXPLICIT 357
+#define TK_TEMPLATE 358
+#define TK_ELLIPSIS 359
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 102 "parser.y"
+#line 105 "parser.y"
 typedef union YYSTYPE {
     char            qchar;
     char            *text;
@@ -253,8 +261,8 @@ typedef union YYSTYPE {
     exceptionDef    exceptionbase;
     classDef        *klass;
 } YYSTYPE;
-/* Line 1285 of yacc.c.  */
-#line 258 "parser.h"
+/* Line 1241 of yacc.c.  */
+#line 266 "parser.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
